summaryrefslogtreecommitdiff
path: root/apps/app_dial.c
diff options
context:
space:
mode:
Diffstat (limited to 'apps/app_dial.c')
-rwxr-xr-xapps/app_dial.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/apps/app_dial.c b/apps/app_dial.c
index 7491d4f9b..e71a616b3 100755
--- a/apps/app_dial.c
+++ b/apps/app_dial.c
@@ -362,7 +362,8 @@ static struct ast_channel *wait_for_answer(struct ast_channel *in, struct localu
ast_indicate(in, AST_CONTROL_PROGRESS);
break;
case AST_CONTROL_OFFHOOK:
- /* Ignore going off hook */
+ case AST_CONTROL_FLASH:
+ /* Ignore going off hook and flash */
break;
case -1:
if (!outgoing->ringbackonly && !outgoing->musiconhold) {